@@ -17,11 +17,12 @@ def find_year(df, use_delta=False):
     res = {}
     for colname in df:
         colregex = re.findall('\d\d\d\d', str(colname))
+        colyear = None
         if len(colregex) >= 1:
             colyear = int(colregex[0])
 
         res[colname] = colyear
-        if use_delta:
+        if colyear and use_delta:
             delta = colyear - curyear
             res[colname] = delta
 
